California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 018 - ACA 4 (RESOLUTION CHAPTER 30), MULLIN. ELECTIONS: VOTING AGE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1428004 | PADILLA BALLOT MEASURE COMMITTEE FOR DEMOCRACY AND JUSTICE - YES ON PROPOSITIONS 16, 17, AND 18; ALEX | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1430333 | LOW AND ASM. KEVIN MULLIN; YES ON 18 - VOTE FOR OUR FUTURE, A BALLOT MEASURE COMMITEE, SPONSORED BY THE CALIFORNIA LEAGUE OF CONSERVATION VOTERS, A COALITION OF YOUTH ADVOCATES, ENVIRONMENTALISTS, TEA | SUPPORT